"""Python library for interacting with Pentair Thermal WiFi API."""

from .async_client import AsyncPentairThermalWifi
from .exceptions import (
    APIError,
    AuthenticationError,
    PentairThermalWifiError,
    SessionExpiredError,
    ThermostatNotFoundError,
)
from .models import (
    AuthResponse,
    Day,
    Event,
    Group,
    Notification,
    RegulationMode,
    Schedule,
    Thermostat,
    ThermostatsResponse,
    UpdateThermostatResponse,
    celsius_to_temp,
    temp_to_celsius,
)
from .sync_client import PentairThermalWifi

__version__ = "0.1.2"

__all__ = [
    # Clients
    "PentairThermalWifi",
    "AsyncPentairThermalWifi",
    # Exceptions
    "PentairThermalWifiError",
    "AuthenticationError",
    "SessionExpiredError",
    "ThermostatNotFoundError",
    "APIError",
    # Models
    "AuthResponse",
    "Thermostat",
    "Group",
    "ThermostatsResponse",
    "UpdateThermostatResponse",
    "Notification",
    "Schedule",
    "Day",
    "Event",
    "RegulationMode",
    # Utilities
    "temp_to_celsius",
    "celsius_to_temp",
    # Version
    "__version__",
]
